/**
 * YAML utilities.
 *
 * @stability stable
 */
export declare class Yaml {
    /**
     * Saves a set of objects as a multi-document YAML file.
     *
     * @param filePath The output path.
     * @param docs The set of objects.
     * @stability stable
     */
    static save(filePath: string, docs: any[]): void;
    /**
     * Stringify a document into yaml.
     *
     * @param doc An object.
     * @stability stable
     */
    static stringify(doc: any): string;
    /**
     * Saves a set of YAML documents into a temp file (in /tmp).
     *
     * @param docs the set of documents to save.
     * @returns the path to the temporary file
     * @stability stable
     */
    static tmp(docs: any[]): string;
    /**
     * Downloads a set of YAML documents (k8s manifest for example) from a URL or a file and returns them as javascript objects.
     *
     * Empty documents are filtered out.
     *
     * @param urlOrFile a URL of a file path to load from.
     * @returns an array of objects, each represents a document inside the YAML
     * @stability stable
     */
    static load(urlOrFile: string): any[];
    /**
     * Utility class.
     */
    private constructor();
}
